@@ -1,19 +1,24 @@
-
-require 5;  # Time-stamp: "2005-01-05 18:20:32 AST"
 package Lingua::EN::Numbers::Years;
-require Exporter;
-@ISA = qw(Exporter);
+$Lingua::EN::Numbers::Years::VERSION = '1.02';
+use 5.006;
 use strict;
+use warnings;
+
 use Lingua::EN::Numbers 1.01 qw(num2en);
 
-use vars qw( @EXPORT @EXPORT_OK $VERSION %DD %D %OhDD    $T $H $Oh $Zero);
-$T  = "thousand";
-$H  = "hundred";
-$Oh = "oh";
-$Zero = "zero";
+require Exporter;
+our @ISA = qw(Exporter);
+
+my $T    = 'thousand';
+my $H    = 'hundred';
+my $Oh   = 'oh';
+my $Zero = 'zero';
+my %DD;
+my %OhDD;
+my %D;
+
+our @EXPORT    = qw(year2en);
 
-$VERSION = '1.01';
-@EXPORT    = qw(year2en);
 BEGIN { *DEBUG = sub () {0} unless defined &DEBUG } # setup a DEBUG constant
 
 #--------------------------------------------------------------------------
@@ -134,6 +139,10 @@ L<Lingua::EN::Numbers>
 
 L<Lingua::EN::WordsToNumbers>
 
+=head1 REPOSITORY
+
+L<https://github.com/neilbowers/Lingua-EN-Numbers-Years>
+
 =head1 COPYRIGHT
 
 Copyright (c) 2005, Sean M. Burke, author of the later versions.
